==> haskell-incremental-parser-0.2.5.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.2.5.2
id: incremental-parser-0.2.5.2-3SaygiHqJ8lAiXXAoPr00B
key: incremental-parser-0.2.5.2-3SaygiHqJ8lAiXXAoPr00B
license: GPL
copyright: (c) 2011-2017 Mario Blazevic
maintainer: blamario@yahoo.com
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
author: Mario Blazevic
exposed: True
indefinite: False
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
abi: 561337223bc5c8314398a6836f8faf09
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/incremental-parser-0.2.5.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/incremental-parser-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/incremental-parser-0.2.5.2
hs-libraries: HSincremental-parser-0.2.5.2-3SaygiHqJ8lAiXXAoPr00B
depends:
    base-4.10.1.0 monoid-subclasses-0.4.4-C1b20V6LixEyYdGkPAUzj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             monoid-subclasses-0.4.4-C1b20V6LixEyYdGkPAUzj=bfb5e3270aa9da7b9090272118eb6267
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.2.5.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: incremental-parser
version: 0.2.5.2
id: incremental-parser-0.2.5.2-43Nb02GztpR2i4cS1msO6R
key: incremental-parser-0.2.5.2-43Nb02GztpR2i4cS1msO6R
license: GPL
copyright: (c) 2011-2017 Mario Blazevic
maintainer: blamario@yahoo.com
homepage: https://github.com/blamario/incremental-parser
synopsis: Generic parser library capable of providing partial results from partial input.
description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.
category: Parsing
author: Mario Blazevic
exposed: True
indefinite: False
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric
abi: 189ac047784ca3bc81575fa572fc5195
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/incremental-parser-0.2.5.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/incremental-parser-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/incremental-parser-0.2.5.2
hs-libraries: HSincremental-parser-0.2.5.2-43Nb02GztpR2i4cS1msO6R
depends:
    base-4.10.1.0 monoid-subclasses-0.4.4-8t8CkOfpl83Fs1yjOtHpaD
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             monoid-subclasses-0.4.4-8t8CkOfpl83Fs1yjOtHpaD=8dcfdd4c8f4f2864424a20d7e3bed7e5
haddock-interfaces: /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock
haddock-html: /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
